@@ -89,6 +89,9 @@ class CromwellHandler(object):
                     rawoutputs = json.loads(jsonitem)
             rawoutputs = rawoutputs["outputs"]
             self.outputs = dict()
+            for key in rawoutputs:
+                rawoutputs[key] = str(rawoutputs[key])
+                print("Raw ->" + key + str(rawoutputs[key]))
             for key in rawoutputs:
                 try:
                     self.outputs[key.split('.')[-1]] = rawoutputs[key]
